# Frequenz Weather API Client Release Notes

## Summary

<!-- Here goes a general summary of what this release is about -->

## Upgrading

* Widen dependency version range of `frequenz-client-base` to  `>= 0.9.0, < 0.12`.

<!-- Here goes notes on how to upgrade from previous versions, including deprecations and what they should be replaced with -->

## New Features

<!-- Here goes the main new features and examples or instructions on how to use them -->

## Bug Fixes

<!-- Here goes notable bug fixes that are worth a special mention or explanation -->
